/* ver.B.b17.01(BLAZE) */


#include "version.h"


VERSION ap_version = {
	"AP.code",
	"xlufr",
	"(C) 2000-2007 Hirohisa Mori and GLOBALBASE Project",
	"ver.B.b17.01(BLAZE)",
	2008,1,11,
	0,
	"GLOBALBASE File Access Grue ",
};

